@@ -27,7 +27,6 @@ from mrjob.util import expand_path
 
 try:
     import simplejson as json  # preferred because of C speedups
-    json  # quiet "redefinition of unused ..." warning from pyflakes
 except ImportError:
     import json  # built in to Python 2.6 and later
 
@@ -164,11 +163,10 @@ def conf_object_at_path(conf_path):
         else:
             try:
                 return json.load(f)
-            except json.JSONDecodeError, e:
+            except ValueError, e:
                 msg = ('If your mrjob.conf is in YAML, you need to install'
                        ' yaml; see http://pypi.python.org/pypi/PyYAML/')
-                # JSONDecodeError currently has a msg attr, but it may not in
-                # the future
+                # Use msg attr if it's set
                 if hasattr(e, 'msg'):
                     e.msg = '%s (%s)' % (e.msg, msg)
                 else:
@@ -315,7 +313,8 @@ def combine_cmds(*cmds):
     """Take zero or more commands to run on the command line, and return
     the last one that is not ``None``. Each command should either be a list
     containing the command plus switches, or a string, which will be parsed
-    with :py:func:`shlex.split`
+    with :py:func:`shlex.split`. The string must either be a byte string or a
+    unicode string containing no non-ASCII characters.
 
     Returns either ``None`` or a list containing the command plus arguments.
     """
@@ -324,7 +323,7 @@ def combine_cmds(*cmds):
     if cmd is None:
         return None
     elif isinstance(cmd, basestring):
-        return shlex.split(cmd)
+        return shlex.split(str(cmd))
     else:
         return list(cmd)
 
