@@ -35,7 +35,7 @@ from mrjob.logparsers import TASK_ATTEMPTS_LOG_URI_RE
 from mrjob.logparsers import STEP_LOG_URI_RE
 from mrjob.logparsers import HADOOP_JOB_LOG_URI_RE
 from mrjob.logparsers import scan_for_counters_in_files
-from mrjob.logparsers import scan_logs_in_order
+from mrjob.logparsers import best_error_from_logs
 from mrjob.parse import HADOOP_STREAMING_JAR_RE
 from mrjob.parse import is_uri
 from mrjob.parse import urlparse
@@ -89,14 +89,21 @@ def fully_qualify_hdfs_path(path):
         return 'hdfs:///user/%s/%s' % (getpass.getuser(), path)
 
 
-def hadoop_log_dir():
-    """Return the path where Hadoop stores logs"""
+def hadoop_log_dir(hadoop_home=None):
+    """Return the path where Hadoop stores logs.
+
+    :param hadoop_home: putative value of :envvar:`HADOOP_HOME`, or None to
+                        default to the actual value if used. This is only used
+                        if :envvar:`HADOOP_LOG_DIR` is not defined.
+    """
     try:
         return os.environ['HADOOP_LOG_DIR']
     except KeyError:
         # Defaults to $HADOOP_HOME/logs
         # http://wiki.apache.org/hadoop/HowToConfigure
-        return os.path.join(os.environ['HADOOP_HOME'], 'logs')
+        if hadoop_home is None:
+            hadoop_home = os.environ['HADOOP_HOME']
+        return os.path.join(hadoop_home, 'logs')
 
 
 class HadoopRunnerOptionStore(RunnerOptionStore):
@@ -204,7 +211,7 @@ class HadoopJobRunner(MRJobRunner):
         # temp dir for input
         self._hdfs_input_dir = None
 
-        self._hadoop_log_dir = hadoop_log_dir()
+        self._hadoop_log_dir = hadoop_log_dir(self._opts['hadoop_home'])
 
         # Running jobs via hadoop assigns a new timestamp to each job.
         # Running jobs via mrjob only adds steps.
@@ -663,10 +670,8 @@ class HadoopJobRunner(MRJobRunner):
                                              HADOOP_JOB_LOG_URI_RE,
                                              step_nums)
         log.info('Scanning logs for probable cause of failure')
-        return scan_logs_in_order(task_attempt_logs=task_attempt_logs,
-                                  step_logs=step_logs,
-                                  job_logs=job_logs,
-                                  runner=self)
+        return best_error_from_logs(self, task_attempt_logs, step_logs,
+                                    job_logs)
 
     ### FILESYSTEM STUFF ###
 
@@ -753,8 +758,9 @@ class HadoopJobRunner(MRJobRunner):
         if not is_uri(path_glob):
             return super(HadoopJobRunner, self).path_exists(path_glob)
 
-        return bool(self._invoke_hadoop(['fs', '-test', '-e', path_glob],
-                                        ok_returncodes=(0, 1)))
+        return_code = self._invoke_hadoop(['fs', '-test', '-e', path_glob],
+                                          ok_returncodes=(0, 1))
+        return (return_code == 0)
 
     def path_join(self, dirname, filename):
         if is_uri(dirname):
