@@ -37,7 +37,6 @@ try:
     StringIO  # quiet "redefinition of unused ..." warning from pyflakes
 except ImportError:
     from StringIO import StringIO
-
 from mrjob import compat
 from mrjob.conf import combine_cmds
 from mrjob.conf import combine_dicts
@@ -61,16 +60,20 @@ GLOB_RE = re.compile(r'^(.*?)([\[\*\?].*)$')
 
 #: cleanup options:
 #:
-#: * ``'ALL'``: delete local scratch, remote scratch, and logs
+#: * ``'ALL'``: delete local scratch, remote scratch, and logs; stop job flow
+#:   if on EMR and the job is not done when cleanup is run.
 #: * ``'LOCAL_SCRATCH'``: delete local scratch only
 #: * ``'LOGS'``: delete logs only
 #: * ``'NONE'``: delete nothing
 #: * ``'REMOTE_SCRATCH'``: delete remote scratch only
 #: * ``'SCRATCH'``: delete local and remote scratch, but not logs
+#: * ``'JOB'``: stop job if on EMR and the job is not done when cleanup runs
+#: * ``'JOB_FLOW'``: terminate the job flow if on EMR and the job is not done
+#:    on cleanup
 #: * ``'IF_SUCCESSFUL'`` (deprecated): same as ``ALL``. Not supported for
 #:   ``cleanup_on_failure``.
 CLEANUP_CHOICES = ['ALL', 'LOCAL_SCRATCH', 'LOGS', 'NONE', 'REMOTE_SCRATCH',
-                   'SCRATCH', 'IF_SUCCESSFUL']
+                   'SCRATCH', 'JOB', 'IF_SUCCESSFUL', 'JOB_FLOW']
 
 #: .. deprecated:: 0.3.0
 #:
@@ -514,6 +517,13 @@ class MRJobRunner(object):
                 for line in self._cat_file(filename):
                     yield line
 
+    def _cleanup_mode(self, mode=None):
+        """Actual cleanup action to take based on various options"""
+        if self._ran_job:
+            return mode or self._opts['cleanup']
+        else:
+            return mode or self._opts['cleanup_on_failure']
+
     def _cleanup_local_scratch(self):
         """Cleanup any files/directories on the local machine we created while
         running this job. Should be safe to run this at any time, or multiple
@@ -545,10 +555,14 @@ class MRJobRunner(object):
         """
         pass  # this only happens on EMR
 
-    def _cleanup_jobs(self):
+    def _cleanup_job(self):
         """Stop any jobs that we created that are still running."""
         pass  # this only happens on EMR
 
+    def _cleanup_job_flow(self):
+        """Terminate the job flow if there is one."""
+        pass  # this only happens on EMR
+
     def cleanup(self, mode=None):
         """Clean up running jobs, scratch dirs, and logs, subject to the
         *cleanup* option passed to the constructor.
@@ -564,17 +578,17 @@ class MRJobRunner(object):
         :param mode: override *cleanup* passed into the constructor. Should be
                      a list of strings from :py:data:`CLEANUP_CHOICES`
         """
-        if self._ran_job:
-            mode = mode or self._opts['cleanup']
-        else:
-            mode = mode or self._opts['cleanup_on_failure']
-
-        # always terminate running jobs
-        self._cleanup_jobs()
+        mode = self._cleanup_mode(mode)
 
         def mode_has(*args):
             return any((choice in mode) for choice in args)
 
+        if mode_has('JOB_FLOW', 'ALL') and not self._ran_job:
+            self._cleanup_job_flow()
+
+        if mode_has('JOB', 'ALL') and not self._ran_job:
+            self._cleanup_job()
+
         if mode_has('ALL', 'SCRATCH', 'LOCAL_SCRATCH', 'IF_SUCCESSFUL'):
             self._cleanup_local_scratch()
 
@@ -1237,6 +1251,12 @@ class MRJobRunner(object):
         env = os.environ.copy()
         env['LC_ALL'] = 'C'
 
+        # Make sure that the base tmp dir environment variables are changed if
+        # the default is changed.
+        env['TMP'] = self._opts['base_tmp_dir']
+        env['TMPDIR'] = self._opts['base_tmp_dir']
+        env['TEMP'] = self._opts['base_tmp_dir']
+
         log.info('writing to %s' % output_path)
 
         err_path = os.path.join(self._get_local_tmp_dir(), 'sort-stderr')
